@@ -3,7 +3,7 @@ __all__ = ['embed_download']
 from ..common import *
 
 from .iqiyi import iqiyi_download_by_vid
-from .letv import letvcloud_download_by_vu
+from .le import letvcloud_download_by_vu
 from .qq import qq_download_by_vid
 from .sina import sina_download_by_vid
 from .tudou import tudou_download_by_id
